pub enum BlankLinePosition {
BeforeItem {
first_code_line: String,
},
BeforeCode {
first_code_line: String,
},
}Expand description
Describes where a blank line should be inserted relative to a body item.
Variants
BeforeItem
Insert blank line before the item (including its leading comments).
The first_code_line is the item’s first code line (without comments)
used as a search anchor in the output.
BeforeCode
Insert blank line between the item’s leading comments and its code.
The first_code_line is used to find where the code starts.