Emit an SWC Module to a string via swc_ecma_codegen.
If transform was called on the same thread, any comments from the
compiled AST are automatically included.
Emit an SWC Module to a string, optionally including comments.
blank_line_positions describes where blank lines should be inserted
to match Babel’s blank line behavior.
Normalize source code formatting to match Babel’s codegen behavior.
Applied to source text that was not modified by the compiler.
Currently adds blank lines after directive sequences, matching
Babel’s generator which always emits a blank line after the last
directive in a function/program body.