pub fn normalize_source(source: &str) -> StringExpand description
Normalize source code formatting to match Babel’s codegen behavior. Applied to source text that was not modified by the compiler. Currently adds blank lines after directive sequences, matching Babel’s generator which always emits a blank line after the last directive in a function/program body.